Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/gameengine/Converter/BL_ArmatureObject.cpp')
-rw-r--r--source/gameengine/Converter/BL_ArmatureObject.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/source/gameengine/Converter/BL_ArmatureObject.cpp b/source/gameengine/Converter/BL_ArmatureObject.cpp
index f9ddc258cfe..f38782a9405 100644
--- a/source/gameengine/Converter/BL_ArmatureObject.cpp
+++ b/source/gameengine/Converter/BL_ArmatureObject.cpp
@@ -61,7 +61,7 @@
/**
* Move here pose function for game engine so that we can mix with GE objects
* Principle is as follow:
* Use Blender structures so that where_is_pose can be used unchanged
* Copy the constraint so that they can be enabled/disabled/added/removed at runtime
* Don't copy the constraints for the pose used by the Action actuator, it does not need them.
* Scan the constraint structures so that the KX equivalent of target objects are identified and
@@ -84,7 +84,7 @@ void game_copy_pose(bPose **dst, bPose *src, int copy_constraint)
return;
}
else if (*dst==src) {
- printf("copy_pose source and target are the same\n");
+ printf("BKE_pose_copy_data source and target are the same\n");
*dst=NULL;
return;
}
@@ -129,7 +129,7 @@ void game_copy_pose(bPose **dst, bPose *src, int copy_constraint)
BLI_ghash_free(ghash, NULL, NULL);
// set acceleration structure for channel lookup
- make_pose_channels_hash(out);
+ BKE_pose_channels_hash_make(out);
*dst=out;
}
@@ -200,7 +200,7 @@ void game_free_pose(bPose *pose)
{
if (pose) {
/* free pose-channels and constraints */
- free_pose_channels(pose);
+ BKE_pose_channels_free(pose);
/* free IK solver state */
BIK_clear_data(pose);
@@ -225,7 +225,7 @@ BL_ArmatureObject::BL_ArmatureObject(
m_poseChannels(),
m_objArma(armature),
m_framePose(NULL),
- m_scene(scene), // maybe remove later. needed for where_is_pose
+ m_scene(scene), // maybe remove later. needed for BKE_pose_where_is
m_lastframe(0.0),
m_timestep(0.040),
m_activeAct(NULL),
@@ -477,7 +477,7 @@ void BL_ArmatureObject::ApplyPose()
}
// update ourself
UpdateBlenderObjectMatrix(m_objArma);
- where_is_pose(m_scene, m_objArma); // XXX
+ BKE_pose_where_is(m_scene, m_objArma); // XXX
// restore ourself
memcpy(m_objArma->obmat, m_obmat, sizeof(m_obmat));
// restore active targets
@@ -590,7 +590,7 @@ bool BL_ArmatureObject::GetBoneMatrix(Bone* bone, MT_Matrix4x4& matrix)
bPoseChannel *pchan;
ApplyPose();
- pchan = get_pose_channel(m_objArma->pose, bone->name);
+ pchan = BKE_pose_channel_find_name(m_objArma->pose, bone->name);
if (pchan)
matrix.setValue(&pchan->pose_mat[0][0]);
RestorePose();
@@ -61,7 +61,7 @@
* Move here pose function for game engine so that we can mix with GE objects
* Principle is as follow:
- * Use Blender structures so that where_is_pose can be used unchanged
+ * Use Blender structures so that BKE_pose_where_is can be used unchanged
* Copy the constraint so that they can be enabled/disabled/added/removed at runtime
* Don't copy the constraints for the pose used by the Action actuator, it does not need them.